@@ -40,6 +40,7 @@ A construct to create a private asset S3 bucket. Cognito will be used for token
     const privateAssetBucket = new PrivateAssetBucket(stack, 'privateAssetBucket', {
       userPoolId: userPool.userPoolId,
       userPoolClientId: userPoolWebClient.userPoolClientId,
+      tokenUse: 'access',
     });
 
     new core.CfnOutput(stack, 'AssetBucketName', {
@@ -188,6 +189,7 @@ class PrivateAssetBucket(
         asset_bucket_name: typing.Optional[builtins.str] = None,
         asset_bucket_name_import: typing.Optional[builtins.str] = None,
         custom_domain: typing.Optional[CustomDomain] = None,
+        token_use: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
@@ -197,6 +199,7 @@ class PrivateAssetBucket(
         :param asset_bucket_name: 
         :param asset_bucket_name_import: if you want to use an imported bucket instead.
         :param custom_domain: 
+        :param token_use: The token use that you expect to be present in the JWT's token_use claim. Usually you are verifying either Access token (common) or ID token (less common). Pass null explicitly to not check the JWT's token use--if you know what you're doing
         '''
         props = PrivateAssetBucketProps(
             user_pool_client_id=user_pool_client_id,
@@ -204,6 +207,7 @@ class PrivateAssetBucket(
             asset_bucket_name=asset_bucket_name,
             asset_bucket_name_import=asset_bucket_name_import,
             custom_domain=custom_domain,
+            token_use=token_use,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -248,6 +252,7 @@ class PrivateAssetBucket(
         "asset_bucket_name": "assetBucketName",
         "asset_bucket_name_import": "assetBucketNameImport",
         "custom_domain": "customDomain",
+        "token_use": "tokenUse",
     },
 )
 class PrivateAssetBucketProps:
@@ -259,6 +264,7 @@ class PrivateAssetBucketProps:
         asset_bucket_name: typing.Optional[builtins.str] = None,
         asset_bucket_name_import: typing.Optional[builtins.str] = None,
         custom_domain: typing.Optional[CustomDomain] = None,
+        token_use: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param user_pool_client_id: 
@@ -266,6 +272,7 @@ class PrivateAssetBucketProps:
         :param asset_bucket_name: 
         :param asset_bucket_name_import: if you want to use an imported bucket instead.
         :param custom_domain: 
+        :param token_use: The token use that you expect to be present in the JWT's token_use claim. Usually you are verifying either Access token (common) or ID token (less common). Pass null explicitly to not check the JWT's token use--if you know what you're doing
         '''
         if isinstance(custom_domain, dict):
             custom_domain = CustomDomain(**custom_domain)
@@ -279,6 +286,8 @@ class PrivateAssetBucketProps:
             self._values["asset_bucket_name_import"] = asset_bucket_name_import
         if custom_domain is not None:
             self._values["custom_domain"] = custom_domain
+        if token_use is not None:
+            self._values["token_use"] = token_use
 
     @builtins.property
     def user_pool_client_id(self) -> builtins.str:
@@ -308,6 +317,16 @@ class PrivateAssetBucketProps:
         result = self._values.get("custom_domain")
         return typing.cast(typing.Optional[CustomDomain], result)
 
+    @builtins.property
+    def token_use(self) -> typing.Optional[builtins.str]:
+        '''The token use that you expect to be present in the JWT's token_use claim.
+
+        Usually you are verifying either Access token (common) or ID token (less common).
+        Pass null explicitly to not check the JWT's token use--if you know what you're doing
+        '''
+        result = self._values.get("token_use")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
